@@ -5,7 +5,7 @@ Weasel::DriverRole - API definition for driver wrappers
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ use Carp;
 use Moose::Role;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 ATTRIBUTES
 
@@ -176,7 +176,7 @@ sub is_displayed {
     croak q{Abstract interface method 'is_displayed' called};
 }
 
-=item wait_for( $callback, retry_timeout => $num, poll_delay => $num )
+=item wait_for( $callback, retry_timeout => $num, poll_delay => $num, on_timeout => \&cb )
 
 The driver may interpret the 'poll_delay' in one of two ways:
  1. The 'poll_delay' equals the number of seconds between the start of
@@ -184,6 +184,9 @@ The driver may interpret the 'poll_delay' in one of two ways:
  2. The 'poll_delay' equals the number of seconds to wait between the end
     of one poll request and the start of the next
 
+I<Since 0.03:> Unless an C<on_timeout> callback is provided, will C<die>
+when the timeout has exceeded. Otherwise, call the provided callback.
+
 Note: The user should catch inside the callback any exceptions that are
   thrown inside the callback, unless such exceptions are allowed to
   terminate further polling attempts.
@@ -263,6 +266,8 @@ sub get_text {
 
 =item set_attribute($element_id, $attribute_name, $value)
 
+DEPRECATED
+
 Changes the value of the attribute named by C<$attribute_name> to C<$value>
 for the element identified by C<$element_id>.
 
@@ -274,6 +279,10 @@ sub set_attribute {
 
 =item get_selected($element_id)
 
+DEPRECATED
+
+Please use C<$self->get_attribute('selected')> instead.
+
 =cut
 
 sub get_selected {
@@ -282,6 +291,10 @@ sub get_selected {
 
 =item set_selected($element_id, $value)
 
+DEPRECATED
+
+Please use C<$self->set_attribute('selected', $value)> instead.
+
 =cut
 
 sub set_selected {
